# RestSQL

# 测试

* [x] Gen data
  * [x] pgsql
  * [x] mysql
* [x] Model测试
* [ ] Engine测试
  * [x] SqlEngine
    * [x] pgsql
    * [x] mysql
  * [ ] EsEngine
* [ ] Query测试
  * [x] pgsql
  * [x] mysql
  * [ ] impala
  * [ ] es
